package com.pm.dbmahasiswa;


import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

public class DBAMahasiswa {
    public static final String KEY_NIM = "NIM";  
    public static final String KEY_NAMA = "Nama";
    public static final String KEY_ALAMAT = "Alamat";
    public static final String KEY_TGL_LAHIR = "Tgl_Lahir";
    
    private static final String TAG = "DBAdapter";
    
    private static final String DATABASE_NAME = "dbMhs";
    private static final String DATABASE_TABLE = "Mahasiswa";
    private static final int DATABASE_VERSION = 3;

    private static final String DATABASE_MAHASISWA_CREATE =
        "create table if not exists Mahasiswa (NIM VARCHAR primary key, "
        + "Nama VARCHAR, Alamat VARCHAR, Tgl_Lahir VARCHAR);";    
    
    private final Context context;    

    private DatabaseHelper DBHelper;
    private SQLiteDatabase db;

    public DBAMahasiswa(Context ctx) 
    {
        this.context = ctx;
        DBHelper = new DatabaseHelper(context);
    }
        
    private static class DatabaseHelper extends SQLiteOpenHelper 
    {
        DatabaseHelper(Context context) 
        {
            super(context, DATABASE_NAME, null, DATABASE_VERSION);
        }

        @Override
        public void onCreate(SQLiteDatabase db) 
        {
        	try {        		
        		db.execSQL(DATABASE_MAHASISWA_CREATE);        		
        	} catch (SQLException e) {
        		e.printStackTrace();
        	}
        }

        @Override
        public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) 
        {
            Log.w(TAG, "Upgrading database from version " + oldVersion + " to "
                    + newVersion + ", which will destroy all old data");
            db.execSQL("DROP TABLE IF EXISTS Mahasiswa");
            onCreate(db);
        }
    }    

    //---opens the database---
    public DBAMahasiswa open() throws SQLException 
    {
        db = DBHelper.getWritableDatabase();
        return this;
    }

    //---closes the database---    
    public void close() 
    {
        DBHelper.close();
    }
    //---insert a record into the database---
    public long insertRecord(String NIM, String Nama, 
    		String Alamat, String TglLahir) 
    {
        ContentValues initialValues = new ContentValues();        
        initialValues.put(KEY_NIM, NIM);        
        initialValues.put(KEY_NAMA, Nama);
        initialValues.put(KEY_ALAMAT, Alamat);
        initialValues.put(KEY_TGL_LAHIR, TglLahir);
        return db.insert(DATABASE_TABLE, null, initialValues);
    }

    //---deletes a particular record---
    public boolean deleteAllRecord() 
    {
        return db.delete(DATABASE_TABLE, null, null) > 0;
    }
    
    //---deletes a particular record---
    public boolean deleteRecord(String NIM) 
    {
        return db.delete(DATABASE_TABLE, KEY_NIM + "='" + NIM +"'", null) > 0;
    }

    //---retrieves all the records---
    public Cursor getAllRecords() 
    {
        return db.query(DATABASE_TABLE, new String[] {KEY_NIM,  
    		KEY_NAMA, KEY_ALAMAT, KEY_TGL_LAHIR}, 
    		null, null, null, null, null);
    }

    //---retrieves a particular record---
    public Cursor getRecord(String NIM) throws SQLException 
    {
        Cursor mCursor =
            db.query(true, DATABASE_TABLE, new String[] {KEY_NIM,  
    		KEY_NAMA, KEY_ALAMAT, KEY_TGL_LAHIR}, 
            KEY_NIM + "=" + NIM, null, null, null, null, null);
        if (mCursor != null) {
            mCursor.moveToFirst();
        }
        return mCursor;
    }

    //---updates a record---
    public boolean updateRecord(String NIM, String Nama, 
    		String Alamat, String TglLahir) 
    {
        ContentValues args = new ContentValues();        
        args.put(KEY_NAMA, Nama);
        args.put(KEY_ALAMAT, Alamat);
        args.put(KEY_TGL_LAHIR, TglLahir);        
        return db.update(DATABASE_TABLE, args, KEY_NIM + "='" + NIM + "'", null) > 0;
    }
}